SystemOrganization addCategory: #Estanciero!

TestCase subclass: #TestsEstanciero
	instanceVariableNames: 'apo fede agus banco tablero salida formosa zonaSurF zonaCentroF zonaNorteF premioGanadero empresaPetrolera salta zonaSurS zonaCentroS zonaNorteS bodega tucuman zonaSurT zonaNorteT fabrica cordoba zonaSurC zonaCentroC zonaNorteC juego prision'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:03'!
setUp 
	
	"Creamos banco"
	banco := Banco new.
	
	"Creamos tablero"
	tablero := Tablero creaUnTableroConBanco: banco.
		
	"Creamos jugadores"
	apo := Jugador crearUnParticipanteConEstrategia: Standard YDinero: 50000 enElTablero: tablero. 
	fede := Jugador crearUnParticipanteConEstrategia: Standard YDinero: 10000 enElTablero: tablero.
	agus := Jugador crearUnParticipanteConEstrategia: Standard YDinero: 100000 enElTablero: tablero.
	
	"Creamos Casilleros de salida, prision y premio"
	salida := Salida creaUnaSalidaEnElTablero: tablero.
	prision := Casillero creaUnaPrisionEnElTablero: tablero.
	premioGanadero := Premio creaUnPremioEnElTablero: tablero.

	"Creamos provincias"
	formosa := Provincia creaProvinciaConTablero: tablero.
	salta := Provincia creaProvinciaConTablero: tablero.
	tucuman := Provincia creaProvinciaConTablero: tablero.
	cordoba := Provincia creaProvinciaConTablero: tablero.

	"Creamos campos"		
	zonaSurF := Campo unCampoEn: formosa conPrecio: 1000 conValorRenta: 500 conUnCostoDeConstruccionDeEstancia: 500 conDueo: apo.
	zonaCentroF := Campo unCampoEn: formosa conPrecio: 1000 conValorRenta: 500 conUnCostoDeConstruccionDeEstancia: 250 conDueo: fede.
	zonaNorteF := Campo unCampoEn: formosa conPrecio: 1200 conValorRenta: 600 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaSurS := Campo unCampoEn: salta conPrecio: 2600 conValorRenta: 800 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaCentroS := Campo unCampoEn: salta conPrecio: 2600 conValorRenta: 850 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaNorteS := Campo unCampoEn: salta conPrecio: 3000 conValorRenta: 900 conUnCostoDeConstruccionDeEstancia: 350 conDueo: banco.
	zonaSurT := Campo unCampoEn: tucuman conPrecio: 5000 conValorRenta: 1000 conUnCostoDeConstruccionDeEstancia: 400 conDueo: apo.
	zonaNorteT := Campo unCampoEn: tucuman conPrecio: 5400 conValorRenta: 1200 conUnCostoDeConstruccionDeEstancia: 500 conDueo: apo.
	zonaNorteT cantidadEstancias: 1.
	zonaSurC := Campo unCampoEn: cordoba conPrecio: 6000 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 800 conDueo: fede.
	zonaCentroC := Campo unCampoEn: cordoba conPrecio: 6000 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 800 conDueo: fede.
	zonaNorteC:= Campo unCampoEn: cordoba conPrecio: 6400 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 900 conDueo: fede.

	"Creamos empresas"	
	fabrica := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 150 EnElTablero: tablero ConPrecio: 380 conDueo: banco.
	bodega := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 150 EnElTablero: tablero ConPrecio: 380 conDueo: fede.
	empresaPetrolera := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 200 EnElTablero: tablero ConPrecio: 380 conDueo: fede.

	"Creamos juego"
	juego := Juego creaUnJuegoConTablero: tablero yJugadores: {apo.fede.agus} asOrderedCollection.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testAlConsultarLosDueosDeFormosaDevuelveApoFedeYBanco
	
	|dueosDeFormosa|
	
	dueosDeFormosa := formosa dueos.
	self assert: (dueosDeFormosa includes: apo).
	self assert: (dueosDeFormosa includes: fede).
	self assert: (dueosDeFormosa includes: banco).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testAlConsultarLosDueosDeTucumanDevuelveApo
	
	|dueosDeTucuman|
	
	dueosDeTucuman := tucuman dueos.
	self assert: (dueosDeTucuman allSatisfy: [:dueo | dueo=apo]).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoCompraLaFabricaYAlConsultarLaRentaParaFedeDevuelveUnNumeroEntre60000Y360000

	fabrica := Empresa new.
	fabrica tablero: tablero.
	fabrica precio: 380.
	fabrica dueo: banco.
	apo comprar: fabrica.
	self assert: ((60000 to: 360000) includes: (fabrica rentaPara: fede)).     ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoConstruyeEstanciaEnZonaSurTucumanSuDineroPasaASer49600YElCampoPasaATenerUnaEstancia

	zonaSurT agregarEstanciaDe: apo.
	self assert: apo dinero equals: 49600.
	self assert: zonaSurT cantidadEstancias equals: 1.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoHipotecaZonaNorteTucumanLaPropiedadPasaASerDelBancoYApoQuedaConCincuentaYDosMilNovecientosCincuenta
	
	apo hipotecaLaPropiedad: zonaNorteT.
	self assert: zonaNorteT dueo equals: banco.
	self assert: apo dinero equals: 52950.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoIntentaAgregarEstanciaEnZonaCentroFormosaYSeLanzaErrorYSuDineroYLaCantidadDeEstanciasDelCampoQuedanIntactas

	|dineroAnterior cantEstanciasAnterior|
	
	dineroAnterior := apo dinero.
	cantEstanciasAnterior := zonaCentroF cantidadEstancias.
	self should: [zonaCentroF agregarEstanciaDe: apo.] raise: NoSePuedeConstruirEstanciaError.   
	self assert: apo dinero equals: dineroAnterior.
	self assert: zonaSurT cantidadEstancias equals: cantEstanciasAnterior.
	    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoIntentaConstruirEstanciaEnZonaNorteTucumanYSaltaError

	self should: [zonaNorteT agregarEstanciaDe: apo.] raise: NoSePuedeConstruirEstanciaError.   
	
	    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoLePaga10000AFedeYFedeAumentaSuDineroA20000YAApoLeQuedan40000.

	apo paga: 10000 a: fede.
	self assert: fede dinero equals: 20000.
	self assert: apo dinero equals: 40000.     ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testApoPasaPorLaZonaCentroDeFormosaYElYFedeMantieneSuDinero

	|dineroAnteriorFede dineroAnteriorApo|
	
	dineroAnteriorApo := apo dinero.
	dineroAnteriorFede := fede dinero.
	zonaCentroF paso: apo.
	self assert: dineroAnteriorApo equals: apo dinero.
	self assert: dineroAnteriorFede equals: fede dinero.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testConsultarLaRentaDeLaBodegaParaApoYDevuelveEntre120000Y720000

	bodega := Empresa new.
	bodega tablero: tablero.
	bodega precio: 380.
	bodega dueo: fede.
	self assert: ((120000 to: 720000) includes: (bodega rentaPara: apo)).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testConsultarLaRentaDeLaZonaNorteDeTucumanParaFedeYDevuelve2400

	self assert: (zonaNorteT rentaPara: fede) equals: 2400.    
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testConsultarLaRentaDeLaZonaSurDeTucumanParaFedeYEs1000

	self assert: (zonaSurT rentaPara: fede) equals: 1000.    
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnLaPrisionYMantieneSusPropiedadesSuDineroYSigueLibre

	|dineroAnterior propiedadesAnterirores|
	
	dineroAnterior := fede dinero.
	propiedadesAnterirores := fede propiedades.
	prision cayo: fede.  
	self assert: fede dinero equals: dineroAnterior.
	self assert: propiedadesAnterirores == fede propiedades.
	self assert: fede estasLibre.     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnLaSalidaYSuDineroPasaASer10000

	salida cayo: fede.
	self assert: fede dinero equals: 10000.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnLaZonaCentroDeFormosaYSuDineroNoSeModifica

	|dineroAnterior|
	
	dineroAnterior := fede dinero.
	zonaCentroF cayo: fede.  
	self assert: dineroAnterior equals: fede dinero.     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnLaZonaSurDeSaltaYLaCompraYSuDineroPasaASer7400

	zonaSurS cayo: fede.
	self assert: (fede propiedades includes: zonaSurS).
	self assert: fede dinero equals: 7400.      
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnLaZonaSurDeTucumanFedePasaATener9000yApo51000
	
	zonaSurT cayo: fede.
	self assert: fede dinero equals: 9000.
	self assert: apo dinero equals: 51000.      
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCaeEnPremioGanaderoYSuDineroPasaASer12500

	premioGanadero cayo: fede.
	self assert: fede dinero equals: 12500.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeCompraLaZonaCentroDeCordobaEstandoHipotecadaYFedePasaATener1000YEsDueoDeLaZonaQueYaNoEstaHipotecada
	
	zonaCentroC hipotecate.
	fede comprar: zonaCentroC.
	self assert: fede dinero equals: 1000.
	self assert: zonaCentroC dueo equals: fede.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeEstaEnPremioGanaderoYJuegaYEstaEnOtroCasillero

	|numeroDado  casilleros |
	
	fede posicionEnTablero: premioGanadero .
	numeroDado := fede tirarDados.
	[fede estado jugo: fede saco: numeroDado .] on: EstasEnBancarrotaError do: [:e | self jugadores remove: fede .].
	self deny: (fede posicionEnTablero = premioGanadero).  	
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeEstaPresoHace1TurnoSaca4Y5YSiguePreso

	fede ponetePreso.
	fede cantidadTurnosPreso: 1.
	fede saco: 4 y: 5.
	fede estado jugo: fede saco: 9. 
	self assert: (fede estasPreso).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeEstaPresoHace1TurnoSacaDoble3YEstaLibre

	fede ponetePreso.
	fede cantidadTurnosPreso: 1.
	fede saco: 3 y: 3.
	fede estado jugo: fede saco: 6. 
	self assert: (fede estasLibre).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeEstaPresoHace3TurnosYSaqueLoQueSaqueEstaLibre

	fede ponetePreso.
	fede cantidadTurnosPreso:3.
	fede saco: 1 y: 6 .
	fede estado jugo: fede saco: 7.         
	self assert: (fede estasLibre).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeHipotecaLaBodegaQuePasaASerDelBancoYFedeQuedaConDiezMilCientoNoventaPesos
	
	fede hipotecaLaPropiedad: bodega.
	self assert: bodega dueo equals: banco.
	self assert: fede dinero equals: 10190.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeHipotecaZonaNorteCordobaLaPropiedadPasaASerDelBancoYFedeQuedaConTreceMilDoscientos
	
	fede hipotecaLaPropiedad: zonaNorteC.
	self assert: zonaNorteC dueo equals: banco.
	self assert: fede dinero equals: 13200.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeLePaga12000AApoEntoncesFedeHipotecaLaZonaNorteDeCordobaYQuedariaCon1200Pesos
	
	fede hipotecaLaPropiedad: zonaNorteC.
	fede paga: 12000 a: apo.
	self assert: fede dinero equals: 1200.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedeLePaga50000AApoTieneQueSerUnErrorDeBancarrotaYNoDebeModificarseElDinero
	
	| dineroApo dineroFede |
	
	dineroApo := apo dinero.
	dineroFede := fede dinero.
	self should: [fede paga: 50000 a: apo.] raise: EstasEnBancarrotaError.
	"self assert: apo dinero = dineroApo & (fede dinero = dineroFede). error de enunciado ya el el participante va hipotecando las propiedades y va recibiendo la plata de la hipoteca (ya habiamos preguntado si primero teniamos que fijarnos si podia y despues hipotecar o solo hipotecar hasta que pueda pagar o se quede en bancarrota y la respuesta fue que solo hipoteca hasta que o pueda pagar o quede en bancarrota) "
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedePasaPorLaPrisionYMantieneSusPropiedadesSuDineroYSigueLibre

	|dineroAnterior propiedadesAnterirores|
	
	dineroAnterior := fede dinero.
	propiedadesAnterirores := fede propiedades.
	prision paso: fede.  
	self assert: fede dinero equals: dineroAnterior.
	self assert: (propiedadesAnterirores == fede propiedades).
	self assert: fede estasLibre.     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
testFedePasaPorLaSalidaYSuDineroEs15000

	salida paso: fede.
	self assert: fede dinero equals: 15000.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testFedePasaPorPremioGanaderoYMantieneSuDinero

	|dineroAnterior|
	
	dineroAnterior := fede dinero.
	premioGanadero paso: fede.
	self assert: fede dinero equals: dineroAnterior.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testFedeSacaDoble2YLuegoSaca4y5YNoEstaPreso

	fede saco: 2 y: 2.
	fede estado jugo: fede saco: 4.   
	fede saco: 4 y: 5.
	fede estado jugo: fede saco: 9.
	self deny: (fede estasPreso).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testFedeSacaDoble2YLuegoSacaDoble4YEstaPreso

	fede saco: 2 y: 2.
	fede estado jugo: fede saco: 4.   
	fede saco: 4 y: 4.
	fede estado jugo: fede saco: 8.
	self assert: (fede estasPreso).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testFedeSeMuevePorZonaCentroDeCordobaSalidaYZonaSurDeFormosaSuDineroPasaASer14500YQuedaEnZonaSurDeFormosa

	|casilleros|
	
	casilleros := OrderedCollection new.
	casilleros add: zonaNorteC .
	casilleros add: salida .
	casilleros add: zonaSurF.
	
	fede moveteUnos: casilleros.
	self assert: fede dinero equals: 14500.
	self assert: fede posicionEnTablero equals: zonaSurF.        ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testLaCantidadDeEmpresasDeFedeEs2

	self assert: fede cantidadEmpresas equals: 2.    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiApoEsGarcaYCaeFabricaEntoncesLaCompraYQuedaCon49620Pesos
	
	apo estrategia: Garca new.
	fabrica cayo: apo.
	self assert: fabrica dueo equals: apo.
	self assert: apo dinero equals: 49620.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiApoEsImperialistaYCaeFabricaEntoncesLaCompraYQuedaCon49620Pesos
	
	| dineroAnterior |

	dineroAnterior := apo dinero.	
	apo estrategia: Imperialista new.
	fabrica cayo: apo.
	self assert: fabrica dueo equals: banco.
	self assert: apo dinero equals: dineroAnterior.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiApoEsImperialistaYCaeFabricaEntoncesNoLaCompraYElDineroLeQuedaIgual
	
	| dineroAnterior |

	dineroAnterior := apo dinero.	
	apo estrategia: Imperialista new.
	fabrica cayo: apo.
	self assert: fabrica dueo equals: banco.
	self assert: apo dinero equals: dineroAnterior.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiApoEsImperialistaYCaeZonaSurCEntoncesNoLaCompra
	
	apo estrategia: Imperialista new.
	zonaSurC cayo: apo.
	self assert: zonaSurS dueo equals: banco.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiFedeEsGarcaYCaeZonaNorteFYLaCompraQuedaCon8800Pesos
	
	fede estrategia: Garca new.
	zonaNorteF cayo: fede.
	self assert: fede dinero equals: 8800.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiFedeEsGarcaYCaeZonaSurSYLaCompraQuedaCon7400Pesos
	
	fede estrategia: Garca new.
	zonaSurS cayo: fede.
	self assert: fede dinero equals: 7400.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiFedeEsImperialistaYCaeZonaNorteFYLaCompraQuedaCon8800Pesos
	
	fede estrategia: Imperialista new.
	zonaNorteF cayo: fede.
	self assert: fede dinero equals: 8800.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiFedeEsImperialistaYCaeZonaSurSYLaCompraQuedaCon7400Pesos
	
	fede estrategia: Imperialista new.
	zonaSurS cayo: fede.
	self assert: fede dinero equals: 7400.
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testSiJueganApoFedeYAgusEnEseOrdenFedeSeQuedaEnBancarrotaYContinuaAgus
	
	| jugadorSiguiente |
	fede propiedades asSet do: [:propiedad | fede hipotecaLaPropiedad: propiedad .].
	"Antes pusimos : 	fede propiedades do: [:propiedad | fede hipotecaLaPropiedad: propiedad .].
	pero si ves las propiedades Transcript show: fede propiedades. sigue habiendo algunas porque pasa esto?"
	fede dinero: 150.
	jugadorSiguiente := juego jugadores add: juego jugadores removeFirst.
	jugadorSiguiente estado jugo: jugadorSiguiente saco: jugadorSiguiente tirarDados.
	jugadorSiguiente := juego jugadores add: juego jugadores removeFirst.
	self should: 
		[ jugadorSiguiente estado jugo: jugadorSiguiente saco: jugadorSiguiente tirarDados .] 
			raise: EstasEnBancarrotaError.
	jugadorSiguiente := juego jugadores add: juego jugadores removeFirst.
	self assert: jugadorSiguiente equals: agus.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:00'!
testUnaTiradaDeDadosDaEntre2Y12

	self assert: ((2 to: 12) includes: fede tirarDados).    ! !

Object subclass: #Banco
	instanceVariableNames: 'propiedades tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:55'!
agregarPropiedad: nuevaPropiedad

	self propiedades add: nuevaPropiedad.
	nuevaPropiedad dueo: self.! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:55'!
initialize

	propiedades := OrderedCollection new.! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:55'!
propiedades 

	^propiedades.! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:50'!
recibe: unDinero 
	"El banco no recibe plata ya que su dinero es infinito"! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:56'!
tablero

	^tablero! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:56'!
tablero: tableroActual

	tablero := tableroActual.! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:37'!
teVisito: jugador en: propiedad

	jugador compraSiQueres: propiedad.! !

Object subclass: #Casillero
	instanceVariableNames: 'tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Casillero class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:56'!
creaUnaCasilleroEnElTablero: unTablero

	| unCasillero |
	unCasillero := Casillero new.
	unCasillero tablero: unTablero.
	^unCasillero.! !

!Casillero class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:54'!
creaUnaPrisionEnElTablero: unTablero

	| unaPrision |
	unaPrision := Casillero new.
	unaPrision tablero: unTablero.
	unTablero prision: unaPrision.
	^unaPrision.! !

!Casillero methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:56'!
cayo: unJugador
	"Si el casillero no entendio antes que hacer no tiene que hacer nada"! !

!Casillero methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:56'!
paso: unJugador
	"Si el casillero no entendio antes que hacer no tiene que hacer nada"! !

!Casillero methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:21'!
sosEmpresa

	^false.! !

!Casillero methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:21'!
tablero

	^tablero.! !

!Casillero methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:21'!
tablero: tableroActual

	tablero := tableroActual.
	tableroActual agregarCasilleros: self.! !

Casillero subclass: #Premio
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Premio class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:50'!
creaUnPremioEnElTablero: unTablero

	| unPremio |
	unPremio := Premio new.
	unPremio tablero: unTablero.
	^unPremio.! !

!Premio methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:21'!
cayo: jugador

	jugador recibe: 2500.! !

Casillero subclass: #Propiedad
	instanceVariableNames: 'precio dueo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Propiedad subclass: #Campo
	instanceVariableNames: 'provincia valorRenta costoConstruccionEstancia cantidadEstancias'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Campo class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:08'!
unCampoEn: unaProvincia conPrecio: unPrecio conValorRenta: unaRenta conUnCostoDeConstruccionDeEstancia: unCosto conDueo: unDueo
	| nuevoCampo |
	nuevoCampo := Campo new.
	nuevoCampo provincia: unaProvincia.
	unDueo agregarPropiedad:  nuevoCampo.
	nuevoCampo tablero: unaProvincia tablero. "Hace que el casillero entienda cual es su tablero"
	nuevoCampo precio: unPrecio.
	nuevoCampo valorRenta: unaRenta.
	nuevoCampo costoConstruccionEstancia: unCosto.
	^nuevoCampo.! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:22'!
agregarEstanciaDe: jugador

	self provincia verificaConstruccionEn:  self .
	jugador comprarEstanciaEn: self. 
	self cantidadEstancias: self cantidadEstancias + 1. ! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:22'!
cantidadEstancias

	^cantidadEstancias.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:22'!
cantidadEstancias: unaCantEstancias

	cantidadEstancias := unaCantEstancias. ! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:22'!
costoConstruccionEstancia

	^costoConstruccionEstancia.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:22'!
costoConstruccionEstancia: costoActual

	costoConstruccionEstancia := costoActual.! !

!Campo methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:23'!
initialize 

	cantidadEstancias := 0.! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:23'!
provincia

	^provincia.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:23'!
provincia: provinciaActual

	provincia := provinciaActual.
	provinciaActual agregarCampos: self. "Le dice a la provincia que tiene un campo nuevo para agregar"! !

!Campo methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:23'!
renta: cantEstancias

	^(2 raisedTo:  cantEstancias) * valorRenta.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:23'!
rentaPara: jugador

	^self renta: self cantidadEstancias.! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 11:30'!
sosAptaParaElGarca: unJugador 

	| propiedades |
	propiedades := self tablero empresas.
	^propiedades anySatisfy: [:propiedad | (propiedad dueo ~= self dueo) | (propiedad dueo ~= unJugador) .].! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 11:25'!
sosAptaParaElImperialista: unJugador
	
	| propiedades |
	propiedades := self provincia campos.
	^ (propiedades anySatisfy: [:propiedad | propiedad dueo = unJugador .]) | (propiedades allSatisfy: [:propiedad | propiedad dueo = self dueo .]).! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:24'!
valorRenta

	^valorRenta.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:24'!
valorRenta: rentaActual

	valorRenta := rentaActual.! !

Propiedad subclass: #Empresa
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Empresa class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:50'!
creaUnaEmpresaEnElTablero: unTablero ConPrecio: unPrecio conDueo: unDueo

	| unaEmpresa |
	unaEmpresa := Empresa new.
	unaEmpresa tablero: unTablero.
	unaEmpresa precio: unPrecio.
	unDueo agregarPropiedad: unaEmpresa.
	^unaEmpresa.! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
renta: numeroDado

	^numeroDado * 30000 * self dueo cantidadEmpresas.! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
rentaPara: jugador

	^self renta: (jugador tirarDado + jugador tirarDado).! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:29'!
sosAptaParaElGarca: unJugador
	
	| propiedades |
	propiedades := self tablero empresas.
	^propiedades anySatisfy: [:propiedad | (propiedad dueo ~= self dueo) | (propiedad dueo ~= unJugador) .].
	! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:25'!
sosAptaParaElImperialista: unJugador

	^ self tablero empresas allSatisfy: [:propiedad | propiedad dueo = self dueo.] ! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
sosEmpresa

	^true.! !

Empresa subclass: #EmpresaConRentaFija
	instanceVariableNames: 'rentaFija'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!EmpresaConRentaFija class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:50'!
creaUnaEmpresaConRentaFija: unaRentaFija EnElTablero: unTablero ConPrecio: unPrecio conDueo: unDueo

	| unaEmpresa |
	unaEmpresa := EmpresaConRentaFija new.
	unaEmpresa tablero: unTablero.
	unaEmpresa precio: unPrecio.
	unaEmpresa rentaFija: unaRentaFija.
	unDueo agregarPropiedad: unaEmpresa.
	^unaEmpresa.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
rentaFija 

	^rentaFija.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
rentaFija: rentaActual

	rentaFija := rentaActual.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
rentaPara: jugador

	^self rentaFija.! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:21'!
cayo: jugador

	(self dueo ~= jugador) ifTrue: [self dueo teVisito: jugador en: self.].! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:22'!
dueo

	^dueo.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:22'!
dueo: nuevoDueo

	dueo := nuevoDueo.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:22'!
hipotecate

	self precio: self precio * 1.5.
	self dueo: self tablero banco .
	! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:22'!
precio

	^precio.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:22'!
precio: nuevoPrecio

	precio := nuevoPrecio.! !

Casillero subclass: #Salida
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Salida class methodsFor: 'as yet unclassified' stamp: 'Federico 11/15/2012 03:50'!
creaUnaSalidaEnElTablero: unTablero
	
	| unaSalida |
	unaSalida := Salida new.
	unaSalida tablero: unTablero.
	^unaSalida.! !

!Salida methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
paso: unJugador

	unJugador recibe: 5000.! !

Object subclass: #Juego
	instanceVariableNames: 'jugadores tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Juego class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:46'!
creaUnJuegoConTablero: unTablero yJugadores: coleccionDeJugadores
	
	| unJuego |	
	unJuego := self new.
	unJuego tablero: unTablero.
	coleccionDeJugadores do: [:unJugador | unJuego agregarJugador: unJugador . ].
	^unJuego.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
agregarJugador: jugadorNuevo

	jugadores add: jugadorNuevo.
	jugadorNuevo posicionEnTablero: self tablero casilleros first.  "Pone el jugador nuevo en la salida (primer casillero del tablero)"! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
casillerosPara: unJugador con: numeroDado

	^self tablero casillerosDesde: unJugador posicionEnTablero hasta: numeroDado. ! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:24'!
initialize

	jugadores := OrderedCollection new.! !

!Juego methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:25'!
jugadores

	^jugadores.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 22:13'!
queJuegue: unJugador

	| numeroDado |
	numeroDado := unJugador tirarDados.
	[unJugador estado jugo: unJugador saco: numeroDado .] on: EstasEnBancarrotaError do: [:e | self jugadores remove: unJugador .].	
	self queJuegueElQueSigue.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:25'!
queJuegueElQueSigue

	| elQueSigue |
	elQueSigue := self jugadores add: self jugadores removeFirst.
	self queJuegue: elQueSigue.! !

!Juego methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:25'!
tablero

	^tablero.! !

!Juego methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:25'!
tablero: tableroActual

	tablero := tableroActual.! !

Object subclass: #Jugador
	instanceVariableNames: 'propiedades tablero dinero posicionEnTablero cantidadDeDoble cantidadTurnosPreso estado estrategia'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Jugador class methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:59'!
crearUnParticipanteConEstrategia: unaEstrategia YDinero: unDinero enElTablero: unTablero

	| participante |
	participante := self new.
	participante estrategia: unaEstrategia new.  
	participante dinero: unDinero.   
	participante tablero: unTablero.
	participante estado: Libre new.
	participante cantidadTurnosPreso: 0.
	participante cantidadDeDoble: 0.
	^participante.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/16/2012 16:55'!
agregarPropiedad: nuevaPropiedad

	self propiedades add: nuevaPropiedad.
	nuevaPropiedad dueo: self.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:30'!
avanzarPor: casilleros 

	casilleros do: [ : unCasillero | unCasillero paso: self].! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:30'!
caerEn: casillero

	casillero cayo: self.
	self posicionEnTablero: casillero.! !

!Jugador methodsFor: 'getter' stamp: 'AgustinCroce 10/13/2012 16:15'!
cantidadDeDoble 

	^cantidadDeDoble ! !

!Jugador methodsFor: 'setter' stamp: 'AgustinCroce 10/13/2012 16:14'!
cantidadDeDoble: unNumero

	cantidadDeDoble := unNumero .! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:30'!
cantidadEmpresas

	^self propiedades count: [:propiedad | propiedad sosEmpresa. ].! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:29'!
cantidadTurnosPreso

	^cantidadTurnosPreso! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:29'!
cantidadTurnosPreso: cantidadPresoActual

	cantidadTurnosPreso := cantidadPresoActual.! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:29'!
casillerosPara: numeroDado

	^self tablero casillerosDesde: self posicionEnTablero hasta: numeroDado. ! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/16/2012 16:37'!
compraSiQueres: propiedad.

	self estrategia quiere: self comprar: propiedad.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:30'!
comprar: propiedad

	self pagar: propiedad precio.
	self agregarPropiedad: propiedad.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:30'!
comprarEstanciaEn: campo

	self pagar: campo costoConstruccionEstancia . ! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:29'!
dinero

	^dinero.! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:29'!
dinero: dineroActual

	dinero := dineroActual.! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:29'!
estado

	^estado! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:29'!
estado: estadoActual

	estado := estadoActual .! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/14/2012 21:12'!
estasLibre

	^self estado sosLibre.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/14/2012 21:12'!
estasPreso

	^self estado sosPreso.! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:29'!
estrategia

	^estrategia! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:29'!
estrategia: estrategiaActual

	estrategia := estrategiaActual! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:00'!
hipotecaAlgunaPropiedad

	self hipotecaLaPropiedad: self propiedades anyOne..
	
	
	! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:08'!
hipotecaLaPropiedad: propiedad
	
	self recibe: (propiedad precio / 2).
	propiedad sosEmpresa
		ifFalse: [self recibe: (propiedad cantidadEstancias * propiedad costoConstruccionEstancia / 2)].
	propiedad hipotecate.
	self propiedades remove: propiedad.
	
	
	! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/16/2012 16:55'!
initialize

	propiedades := OrderedCollection new.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:41'!
jugaComoLibreSacaste: numeroDado.

	self cantidadDeDoble = 2 ifTrue: [ self ponetePreso .] ifFalse: [ self moveteUnos: (self casillerosPara: numeroDado) .]. ! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:39'!
jugaComoPresoSacaste: numeroDado
	 
	(self cantidadDeDoble = 1) | (self cantidadTurnosPreso = 3) 
		ifTrue: 
			[ self poneteLibre .  
			  self moveteUnos: (self casillerosPara: numeroDado) .] 
		ifFalse: 
			[ self cantidadTurnosPreso: self cantidadTurnosPreso + 1 .].! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:29'!
moveteUnos: casilleros

	self avanzarPor: casilleros.
	self caerEn: casilleros last.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
paga: plata a: otroJugador 

	(self ~= otroJugador) 
		ifTrue: [self pagar: plata.
				otroJugador recibe: plata.].! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
pagar: plata

	self verificaPosiblePago: plata.
	self dinero: self dinero - plata. ! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
poneteLibre 

	self estado: Libre new.
	self cantidadDeDoble: 0.
	self cantidadTurnosPreso: 0.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:13'!
ponetePreso 

	self estado: Preso new.
	self cantidadDeDoble: 0.
	self posicionEnTablero: tablero prision.! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:00'!
posicionEnTablero

	^posicionEnTablero.! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:00'!
posicionEnTablero: posicionActual

	posicionEnTablero := posicionActual.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/16/2012 16:56'!
propiedades 

	^propiedades.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
recibe: unDinero 

	self dinero: self dinero + unDinero.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
sacasteDoble 

	self cantidadDeDoble: self cantidadDeDoble + 1.! !

!Jugador methodsFor: 'accessing' stamp: 'AgustinCroce 10/13/2012 16:03'!
saco: unDado y: otroDado

	unDado = otroDado ifTrue: [self sacasteDoble. ] ifFalse: [self cantidadDeDoble: 0. ]   ! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/16/2012 16:56'!
tablero

	^tablero! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/16/2012 16:56'!
tablero: tableroActual

	tablero := tableroActual.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
teVisito: jugador en: propiedad
	
	| renta |
	renta := propiedad rentaPara: jugador.
	jugador pagar: renta. 
	self recibe: renta.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 10:47'!
tenesQueHipotecarPara: plataAPagar 
	
	self verificaPosibleHipoteca.
	self hipotecaAlgunaPropiedad.
	self dinero >= plataAPagar ifFalse: [self tenesQueHipotecarPara: plataAPagar.].! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
tirarDado

	^(1to: 6) atRandom.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
tirarDados

	| dado1 dado2 |
	dado1 := self tirarDado.
	dado2 := self tirarDado.
	self saco: dado1 y: dado2 .
	^dado1+ dado2.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/3/2012 18:29'!
verificaPosibleHipoteca

	self propiedades size > 0
		ifFalse: 
			[ EstasEnBancarrotaError signal .].! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
verificaPosiblePago: plata
	
	self dinero >= plata ifFalse: [self tenesQueHipotecarPara: plata]! !

Object subclass: #Libre
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:40'!
jugo: unJugador saco: numeroDado
	
	unJugador jugaComoLibreSacaste: numeroDado.! !

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosLibre 

	^true.! !

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:12'!
sosPreso 

	^false.! !

Object subclass: #Preso
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:40'!
jugo: unJugador saco: numeroDado
	
	unJugador jugaComoPresoSacaste: numeroDado.! !

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosLibre 

	^false.! !

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosPreso

	^true.! !

Object subclass: #Provincia
	instanceVariableNames: 'campos tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Provincia class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:35'!
creaProvinciaConTablero: unTablero 

	| unaProvincia |
	unaProvincia := self new.
	unaProvincia tablero: unTablero.
	^unaProvincia.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:25'!
agregarCampos: nuevoCampo

	campos add: nuevoCampo.! !

!Provincia methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:25'!
campos

	^campos.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:25'!
construccionParejaEn: campo

	^campos allSatisfy: [:unCampo | campo cantidadEstancias <= unCampo cantidadEstancias. ].! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
dueos

	^(campos collect: [:unCampo | unCampo dueo. ]) asSet.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
esProvinciaMonopolica

	| dueo |
	dueo := campos first dueo.
	^campos allSatisfy: [:campo | campo dueo = dueo].! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
initialize 

	campos := OrderedCollection new.
	 ! !

!Provincia methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:26'!
tablero

	^tablero.! !

!Provincia methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:26'!
tablero: tableroActual

	tablero := tableroActual.
	tableroActual agregarProvincias: self.! !

!Provincia methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:52'!
verificaConstruccionEn: campo

	(self esProvinciaMonopolica and: [ self construccionParejaEn: campo. ]) ifFalse: [NoSePuedeConstruirEstanciaError signal .].! !

Object subclass: #Standard
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Standard subclass: #Garca
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Garca methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:01'!
quiere: jugador comprar: propiedad
	
	(propiedad sosAptaParaElGarca: jugador ) ifTrue: [ super quiere: jugador comprar: propiedad .].! !

Standard subclass: #Imperialista
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Imperialista methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 17:01'!
quiere: jugador comprar: propiedad

	(propiedad sosAptaParaElImperialista: jugador) ifTrue: [ super quiere: jugador comprar: propiedad .].! !

!Standard methodsFor: 'as yet unclassified' stamp: 'Federico 10/16/2012 16:38'!
quiere: jugador comprar: propiedad

	jugador comprar: propiedad.! !

Object subclass: #Tablero
	instanceVariableNames: 'banco casilleros provincias prision'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Tablero class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 12:57'!
creaUnTableroConBanco: unBanco
	
	| unTablero |
	unTablero := self new.
	unTablero banco: unBanco.
	^unTablero.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
agregarCasilleros: casilleroNuevo

	casilleros add: casilleroNuevo.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
agregarProvincias: nuevaProvincia

	provincias add: nuevaProvincia.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:26'!
banco

	^banco.! !

!Tablero methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:26'!
banco: bancoActual

	banco := bancoActual.
	bancoActual tablero: self.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:26'!
casilleros

	^casilleros.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:26'!
casillerosDesde: casilleroInicial hasta: unNumero

	| misCasilleros recorrido |
	misCasilleros := self casilleros copyAfter: casilleroInicial.
	recorrido := OrderedCollection new.
	[ recorrido size >= unNumero ] whileFalse: [
	misCasilleros ifEmpty: [
	misCasilleros addAll: self casilleros.
	].
	recorrido add: misCasilleros removeFirst. ].

	^recorrido.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 10/15/2012 08:50'!
empresas
	
	^self casilleros select: [:casillero | casillero sosEmpresa . ].
	! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:27'!
initialize

	casilleros := OrderedCollection new.
	provincias := OrderedCollection new.! !

!Tablero methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:27'!
prision

	^ prision.! !

!Tablero methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:12'!
prision: unaPrision 

	prision := unaPrision.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:27'!
provincias

	^provincias.! !

Error subclass: #EstasEnBancarrotaError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Error subclass: #NoSePuedeConstruirEstanciaError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!
